Method: Google::Api::MethodSettings#auto_populated_fields

Defined in:
proto_docs/google/api/client.rb

#auto_populated_fields::Array<::String>

Returns List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.

Example of a YAML configuration:

publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id.

Returns:

  • (::Array<::String>)

    List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.

    Example of a YAML configuration:

    publishing: method_settings: - selector: google.example.v1.ExampleService.CreateExample auto_populated_fields: - request_id



374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'proto_docs/google/api/client.rb', line 374

class MethodSettings
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes settings to use when generating API methods that use the
  # long-running operation pattern.
  # All default values below are from those used in the client library
  # generators (e.g.
  # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)).
  # @!attribute [rw] initial_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Initial delay after which the first poll request will be made.
  #     Default value: 5 seconds.
  # @!attribute [rw] poll_delay_multiplier
  #   @return [::Float]
  #     Multiplier to gradually increase delay between subsequent polls until it
  #     reaches max_poll_delay.
  #     Default value: 1.5.
  # @!attribute [rw] max_poll_delay
  #   @return [::Google::Protobuf::Duration]
  #     Maximum time between two subsequent poll requests.
  #     Default value: 45 seconds.
  # @!attribute [rw] total_poll_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Total polling timeout.
  #     Default value: 5 minutes.
  class LongRunning
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end