Class: Google::Cloud::Parallelstore::V1beta::TransferOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb

Overview

Long-running operation metadata related to a data transfer.

Instance Attribute Summary collapse

Instance Attribute Details

#counters::Google::Cloud::Parallelstore::V1beta::TransferCounters (readonly)

Returns Output only. The progress of the transfer operation.

Returns:



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destination_gcs_bucket::Google::Cloud::Parallelstore::V1beta::DestinationGcsBucket (readonly)

Returns Output only. Cloud Storage destination.

Note: The following fields are mutually exclusive: destination_gcs_bucket, destination_parallelstore. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Parallelstore::V1beta::DestinationGcsBucket)

    Output only. Cloud Storage destination.

    Note: The following fields are mutually exclusive: destination_gcs_bucket, destination_parallelstore. If a field in that set is populated, all other fields in the set will automatically be cleared.



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#destination_parallelstore::Google::Cloud::Parallelstore::V1beta::DestinationParallelstore (readonly)

Returns Output only. Parallelstore destination.

Note: The following fields are mutually exclusive: destination_parallelstore, destination_gcs_bucket. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_gcs_bucket::Google::Cloud::Parallelstore::V1beta::SourceGcsBucket (readonly)

Returns Output only. Cloud Storage source.

Note: The following fields are mutually exclusive: source_gcs_bucket, source_parallelstore. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Parallelstore::V1beta::SourceGcsBucket)

    Output only. Cloud Storage source.

    Note: The following fields are mutually exclusive: source_gcs_bucket, source_parallelstore. If a field in that set is populated, all other fields in the set will automatically be cleared.



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#source_parallelstore::Google::Cloud::Parallelstore::V1beta::SourceParallelstore (readonly)

Returns Output only. Parallelstore source.

Note: The following fields are mutually exclusive: source_parallelstore, source_gcs_bucket. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#transfer_type::Google::Cloud::Parallelstore::V1beta::TransferType (readonly)

Returns Output only. The type of transfer occurring.

Returns:



543
544
545
546
# File 'proto_docs/google/cloud/parallelstore/v1beta/parallelstore.rb', line 543

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end